@@ -178,6 +178,8 @@ SEResamplingMean <- function(initialSample, resamplingMethod=classicalBootstrap,
 
     SEmean <- sum((BertoluzzaDistance(meanMatrix, overallMean, theta))^2)
 
+    SEmean <- sqrt(SEmean / (repetitions - 1))
+
   } else {
 
     # calculate MSE
@@ -186,6 +188,8 @@ SEResamplingMean <- function(initialSample, resamplingMethod=classicalBootstrap,
 
     overallMean <- trueMean
 
+    SEmean <- SEmean / (repetitions - 1)
+
   }
 
 
